/*
 * AJD4JP
 * Copyright (c) 2011  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に
 * 同意できる場合にのみ利用可能です。
 */
package ajd4jp;


/**
 * 十二支。
 */
public enum EarthlyBranch {
	/** 子(ね) */
	SHI( "子" ),
	/** 丑(うし) */
	CHU( "丑" ),
	/** 寅(とら) */
	IN( "寅" ),
	/** 卯(う) */
	BOU( "卯" ),
	/** 辰(たつ) */
	SHIN( "辰" ),
	/** 巳(み) */
	SI( "巳" ),
	/** 午(うま) */
	GO( "午" ),
	/** 未(ひつじ) */
	BI( "未" ),
	/** 申(さる) */
	SIN( "申" ),
	/** 酉(とり) */
	YU( "酉" ),
	/** 戌(いぬ) */
	JUTSU( "戌" ),
	/** 亥(い) */
	GAI( "亥" );

	private String name;
	private EarthlyBranch( String s ) {
		name = s;
	}

	/**
	 * 名称の取得。
	 * @return 子～亥。
	 */
	public String getName() {
		return name;
	}

	/**
	 * 十二支の取得。
	 * @param yy 年。
	 * @return その年を表す十二支。
	 */
	public static EarthlyBranch getYear( int yy ) {
		EarthlyBranch[]	eb = values();
		return eb[(yy - 4) % eb.length];
	}

	/**
	 * 十二支の取得。
	 * @param dd 日。
	 * @return その日を表す十二支。
	 */
	public static EarthlyBranch getDay( Day dd ) {
		EarthlyBranch[]	eb = values();
		return eb[((int)AJD.cut( dd.getAJD() ) - 10) % eb.length];
	}
}

