/*
 * AJD4JP
 * Copyright (c) 2011  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に
 * 同意できる場合にのみ利用可能です。
 */
package ajd4jp;

/**
 * 十干。
 */
public enum HeavenlyStem {
	/** 甲(きのえ) */
	KOU( "甲" ),
	/** 乙(きのと) */
	OTSU( "乙" ),
	/** 丙(ひのえ) */
	HEI( "丙" ),
	/** 丁(ひのと) */
	TEI( "丁" ),
	/** 戊(つちのえ) */
	BO( "戊" ),
	/** 己(つちのと) */
	KI( "己" ),
	/** 庚(かのえ) */
	KO( "庚" ),
	/** 辛(かのと) */
	SHIN( "辛" ),
	/** 壬(みずのえ) */
	JIN( "壬" ),
	/** 癸(みずのと) */
	CI( "癸" );

	private String name;
	private HeavenlyStem( String s ) {
		name = s;
	}
	/**
	 * 名称の取得。
	 * @return 甲～癸。
	 */
	public String getName() {
		return name;
	}

	/**
	 * 十干の取得。
	 * @param yy 年。
	 * @return その年を表す十干。
	 */
	public static HeavenlyStem getYear( int yy ) {
		HeavenlyStem[]	hs = values();
		return hs[(yy - 4) % hs.length];
	}

	/**
	 * 十干の取得。
	 * @param dd 日。
	 * @return その日を表す十干。
	 */
	public static HeavenlyStem getDay( Day dd ) {
		HeavenlyStem[]	hs = values();
		return hs[(int)AJD.cut( dd.getAJD() ) % hs.length];
	}
}

